// -*- Mode: C++; -*-

#ifndef fontsetup_included
#define fontsetup_included

#include "fontsetupData.h"
#include "qfont.h"

class fontsetup : public fontsetupData
{
    Q_OBJECT

public:
    fontsetup(QWidget* parent = NULL,const char* name = NULL);
    virtual ~fontsetup();
    const QFont fixed_font()const{return fixFont;}
    const QFont nonprop_font()const{return nonpropFont;}

protected slots:
    virtual void Type_Selected(int);
    virtual void selected_Font(const QFont&);

signals:
    void snonpropFont(const QFont&);
    void sfixFont(const QFont&);

protected:
    QFont fixFont;
    QFont nonpropFont;
    int last_selected;
};
#endif // fontsetup_included
